@@ -2,8 +2,8 @@
 from sqlalchemy import create_engine
 
 def create_connection():
-    """Connect to postgresql through SQLAlchemy"""
-    database_url = "sqlite:///test_pydango.db"
+    """Connect to SQLite through SQLAlchemy"""
+    database_url = "sqlite:///sqlite3.db"
     engine = create_engine(database_url)
 
     return engine
